decode_into_array_bytes_target

Function decode_into_array_bytes_target 

pub fn decode_into_array_bytes_target(
    bytes: &ArrayBytes<'_>,
    target: ArrayBytesDecodeIntoTarget<'_>,
) -> Result<(), CodecError>
Helper function to decode ArrayBytes into a target, handling mask and data separately.

This function handles the common pattern of decoding ArrayBytes into an ArrayBytesDecodeIntoTarget, properly handling optional data types.

Errors

Returns a CodecError if the bytes are incompatible with the target.