PartialDecoderCapability

Struct PartialDecoderCapability 

pub struct PartialDecoderCapability {
    pub partial_read: bool,
    pub partial_decode: bool,
}
Describes the partial decoding capabilities of a codec.

The capability describes:

  • partial_read: Whether the codec can perform partial reading from its input.
  • partial_decode: Whether the codec supports partial decoding decoding, or it must decode the entire input.

If partial_read is false and partial_decode is true, input should be cached for optimal performance. If partial_decode is false, a cache should be inserted after this codec in a codec chain partial decoder.

Fields

partial_read: bool

Whether the codec can perform partial reading from its input. If false, the codec needs to read all input data before decoding.

partial_decode: bool

Whether the codec supports partial decoding operations. If false, the codec needs to decode the entire input.