pub struct PartialEncoderCapability {
pub partial_encode: bool,
}Expand description
Describes the partial encoding capabilities of a codec.
Fields
partial_encode: boolWhether the codec supports partial encoding operations.
If this returns true, the codec can efficiently handle partial encoding operations if supported by the parent codec or storage handle.
If this returns false, partial encoding will fall back to a full decode and encode operation.